@@ -98,7 +98,9 @@ int output_writeln(struct filter_settings *current_settings, int action, int tar
     if ((action == LOG_ACTION_CHILD_FROM) ||
         (action == LOG_ACTION_FILTER_FROM))
       {
-      if ((return_value = NETWORK_WRITE(current_settings, target_fd, data, data_length)) == -1)
+      if ((return_value = NETWORK_WRITE(current_settings, target_fd, data, data_length)) != -1)
+        SPAMDYKE_LOG_EXCESSIVE(current_settings, LOG_DEBUGX_REMOTE_WRITE, return_value, target_fd, data_length, MINVAL(data_length, LOG_DEBUGX_STRLEN_PREVIEW), data);
+      else
         SPAMDYKE_LOG_VERBOSE(current_settings, LOG_VERBOSE_WRITE "%s", data_length, target_fd, strerror(errno));
       }
     else if (current_settings->tls_state == TLS_STATE_ACTIVE_PASSTHROUGH)
@@ -127,11 +129,15 @@ int output_writeln(struct filter_settings *current_settings, int action, int tar
               ((((data_ptr - data) + i) == 0) &&
                (last_char != CHAR_CR)))
             {
-            if ((i > 0) &&
-                ((return_value = write(target_fd, data_last, (data_ptr - data_last) + i)) == -1))
+            if (i > 0)
               {
-              SPAMDYKE_LOG_VERBOSE(current_settings, LOG_VERBOSE_WRITE "%s", i, target_fd, strerror(errno));
-              break;
+              if ((return_value = write(target_fd, data_last, (data_ptr - data_last) + i)) != -1)
+                SPAMDYKE_LOG_EXCESSIVE(current_settings, LOG_DEBUGX_CHILD_WRITE_CRLF, return_value, target_fd, data_length, MINVAL((data_ptr - data_last) + i, LOG_DEBUGX_STRLEN_PREVIEW), data_last);
+              else
+                {
+                SPAMDYKE_LOG_VERBOSE(current_settings, LOG_VERBOSE_WRITE "%s", i, target_fd, strerror(errno));
+                break;
+                }
               }
 
             data_last = data_ptr + i + 1;
@@ -146,7 +152,10 @@ int output_writeln(struct filter_settings *current_settings, int action, int tar
             }
           else
             if ((return_value = write(target_fd, data_last, (data_ptr - data_last) + i + 1)) != -1)
+              {
+              SPAMDYKE_LOG_EXCESSIVE(current_settings, LOG_DEBUGX_CHILD_WRITE, return_value, target_fd, data_length, MINVAL((data_ptr - data_last) + i + 1, LOG_DEBUGX_STRLEN_PREVIEW), data_last);
               data_last = data_ptr + i + 1;
+              }
             else
               {
               SPAMDYKE_LOG_VERBOSE(current_settings, LOG_VERBOSE_WRITE "%s", i + 1, target_fd, strerror(errno));
@@ -157,7 +166,9 @@ int output_writeln(struct filter_settings *current_settings, int action, int tar
           }
         else
           {
-          if ((return_value = write(target_fd, data_last, (data_ptr - data_last) + i)) == -1)
+          if ((return_value = write(target_fd, data_last, (data_ptr - data_last) + i)) != -1)
+            SPAMDYKE_LOG_EXCESSIVE(current_settings, LOG_DEBUGX_CHILD_WRITE, return_value, target_fd, data_length, MINVAL((data_ptr - data_last) + i, LOG_DEBUGX_STRLEN_PREVIEW), data_last);
+          else
             SPAMDYKE_LOG_VERBOSE(current_settings, LOG_VERBOSE_WRITE "%s", i, target_fd, strerror(errno));
 
           break;
