@@ -10,10 +10,10 @@ cat input.txt | sed -e "s/TEST_NUM/${TEST_NUM}/g" -e "s/TARGET_EMAIL/$1/g" -e "s
 echo "${SENDRECV_PATH} -t 30 -r 221 -- ${SPAMDYKE_PATH} -linfo --log-target stderr ${SMTPDUMMY_PATH} -D < ${TMPDIR}/${TEST_NUM}-input.txt > ${TMPDIR}/${TEST_NUM}-output.txt 2>&1"
 ${SENDRECV_PATH} -t 30 -r 221 -- ${SPAMDYKE_PATH} -linfo --log-target stderr ${SMTPDUMMY_PATH} -D < ${TMPDIR}/${TEST_NUM}-input.txt > ${TMPDIR}/${TEST_NUM}-output.txt 2>&1
 
-output=`grep -E "554 error" ${TMPDIR}/${TEST_NUM}-output.txt`
+output=`grep "554 DATA END rejected" ${TMPDIR}/${TEST_NUM}-output.txt`
 if [ ! -z "${output}" ]
 then
-  output=`grep -E "reason: 554_error" ${TMPDIR}/${TEST_NUM}-output.txt | grep DENIED_OTHER`
+  output=`grep "reason: 554_DATA_END_rejected" ${TMPDIR}/${TEST_NUM}-output.txt | grep DENIED_OTHER`
   if [ ! -z "${output}" ]
   then
     outcome="success"
